@@ -79,12 +79,13 @@ public:
     int         erase_policy(int user, int index, std::string& err);
     int         clear_policies(int user, std::string& err);
 
-    size_t      get_policies_size(int user);
+    size_t      get_policies_size(int user, std::string& err);
     Policy*     get_policy(int user, int pos, std::string& err);
     int         policy_get_name(int user, int id, std::string& name, std::string& err);
-    void        get_policies(int user, const std::vector<int>&, const std::string& format, MediaConchLib::Get_Policies& ps);
+    int         get_policies(int user, const std::vector<int>&, const std::string& format,
+                             MediaConchLib::Get_Policies& ps, std::string& err);
     int         get_public_policies(std::vector<MediaConchLib::Policy_Public_Policy*>& policies, std::string& err);
-    void        get_policies_names_list(int user, std::vector<std::pair<int, std::string> >& ps);
+    int         get_policies_names_list(int user, std::vector<std::pair<int, std::string> >& ps, std::string& err);
     int         policy_get(int user, int pos, const std::string& format, bool must_be_public,
                            MediaConchLib::Get_Policy& policy, std::string& err);
 
