@@ -41,29 +41,35 @@ namespace MediaConch {
 class Policy
 {
 public:
-    Policy(Policies::PolicyType t, bool n_https) : type(t), saved(false), is_system(false), no_https(n_https) {}
+    Policy(Policies *p, Policies::PolicyType t, bool n_https);
     virtual ~Policy();
-    Policy(const Policy*);
 
-    int               import_schema(const std::string& filename, const std::string& save_name);
-    int               import_schema_from_memory(const char* memory, int len, const std::string& save_name);
-    int               export_schema(const char* filename, std::string& err);
-    int               dump_schema(std::string& data);
-    std::string       get_error() const { return error; }
-    virtual xmlDocPtr create_doc() = 0;
+    Policy(const Policy*);
+    Policy(const Policy&);
+
+    int                  import_schema(const std::string& filename, const std::string& save_name);
+    int                  import_schema_from_memory(const char* memory, int len, const std::string& save_name);
+    int                  export_schema(const char* filename, std::string& err);
+    int                  dump_schema(std::string& data);
+    std::string          get_error() const { return error; }
+    virtual xmlDocPtr    create_doc() = 0;
 
     std::string          filename;
-    std::string          title;
+    std::string          name;
     std::string          description;
+    std::string          license;
     Policies::PolicyType type;
-    bool                 saved;
+    size_t               id;
     bool                 is_system;
     bool                 no_https;
+    bool                 is_public;
 
 protected:
+    Policies            *policies;
+    std::string          error;
+
     // HELPER
     virtual int          import_schema_from_doc(xmlDocPtr doc, const std::string& filename) = 0;
-    std::string          error;
 
 private:
     Policy& operator=(const Policy&);
