@@ -27,7 +27,7 @@ namespace MediaConch {
 // SQLLiteReport
 //***************************************************************************
 
-int SQLLiteReport::current_report_version = 4;
+int SQLLiteReport::current_report_version = 5;
 
 //***************************************************************************
 // Constructor/Destructor
@@ -117,6 +117,7 @@ int SQLLiteReport::update_report_table()
     UPDATE_REPORT_TABLE_FOR_VERSION(1);
     UPDATE_REPORT_TABLE_FOR_VERSION(2);
     UPDATE_REPORT_TABLE_FOR_VERSION(3);
+    UPDATE_REPORT_TABLE_FOR_VERSION(4);
 
 #undef UPDATE_REPORT_TABLE_FOR_VERSION
 
@@ -129,15 +130,10 @@ void SQLLiteReport::get_users_id(std::vector<long>& ids, std::string& err)
     reports.clear();
     query = "SELECT USER FROM MEDIACONCH_FILE;";
 
-    const char* end = NULL;
-    int ret = sqlite3_prepare_v2(db, query.c_str(), query.length() + 1, &stmt, &end);
-    if (ret != SQLITE_OK || !stmt || (end && *end))
-    {
-        err = error;
+    if (prepare_v2(query, err) < 0)
         return;
-    }
 
-    if (execute())
+    if (execute() < 0)
     {
         err = error;
         return;
@@ -151,59 +147,94 @@ void SQLLiteReport::get_users_id(std::vector<long>& ids, std::string& err)
 }
 
 long SQLLiteReport::add_file(int user, const std::string& filename, const std::string& file_last_modification,
-                             std::string& err,
+                             const std::string& options, std::string& err,
                              long generated_id,
                              long source_id, size_t generated_time,
                              const std::string& generated_log, const std::string& generated_error_log)
 {
-    long id = get_file_id(user, filename, file_last_modification);
+    std::string opt = options;
+    if (!opt.size())
+        opt = "";
+
+    long id = get_file_id(user, filename, file_last_modification, opt, err);
     if (id >= 0)
         return id;
 
+    err.clear();
+
     std::stringstream create;
 
     reports.clear();
     create << "INSERT INTO MEDIACONCH_FILE";
-    create << " (USER, FILENAME, FILE_LAST_MODIFICATION, GENERATED_ID, SOURCE_ID, GENERATED_TIME, GENERATED_LOG, GENERATED_ERROR_LOG)";
-    create << " VALUES (?, ?, ?, ?, ?, ?, ?, ?);";
+    create << " (USER, FILENAME, FILE_LAST_MODIFICATION, GENERATED_ID, SOURCE_ID, GENERATED_TIME, GENERATED_LOG, GENERATED_ERROR_LOG, OPTIONS)";
+    create << " VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?);";
     query = create.str();
 
-    const char* end = NULL;
-    int ret = sqlite3_prepare_v2(db, query.c_str(), query.length() + 1, &stmt, &end);
-    if (ret != SQLITE_OK || !stmt || (end && *end))
+    if (prepare_v2(query, err) < 0)
         return -1;
 
-    ret = sqlite3_bind_int(stmt, 1, user);
+    int ret = sqlite3_bind_int(stmt, 1, user);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_blob(stmt, 2, filename.c_str(), filename.length(), SQLITE_STATIC);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_blob(stmt, 3, file_last_modification.c_str(), file_last_modification.length(), SQLITE_STATIC);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 4, generated_id);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 5, source_id);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 6, generated_time);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_blob(stmt, 7, generated_log.c_str(), generated_log.length(), SQLITE_STATIC);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_blob(stmt, 8, generated_error_log.c_str(), generated_error_log.length(), SQLITE_STATIC);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
+
+    ret = sqlite3_bind_blob(stmt, 9, opt.c_str(), opt.length(), SQLITE_STATIC);
+    if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
+        return -1;
+    }
 
     if (execute() < 0)
     {
@@ -211,12 +242,12 @@ long SQLLiteReport::add_file(int user, const std::string& filename, const std::s
         return -1;
     }
 
-    id = get_file_id(user, filename, file_last_modification);
+    id = get_file_id(user, filename, file_last_modification, opt, err);
     return id;
 }
 
 long SQLLiteReport::update_file(int user, long file_id, const std::string& file_last_modification,
-                                std::string& err,
+                                const std::string& options, std::string& err,
                                 long generated_id, long source_id, size_t generated_time,
                                 const std::string& generated_log, const std::string& generated_error_log)
 {
@@ -227,45 +258,74 @@ long SQLLiteReport::update_file(int user, long file_id, const std::string& file_
     create << " SET FILE_LAST_MODIFICATION = ?, GENERATED_ID = ?, SOURCE_ID = ?,";
     create << " GENERATED_TIME = ?, GENERATED_LOG = ?, GENERATED_ERROR_LOG = ?,";
     create << " ANALYZED = 0";
-    create << " WHERE ID = ? AND USER = ?;";
+    create << " WHERE ID = ? AND USER = ? AND OPTIONS = ?;";
     query = create.str();
 
-    const char* end = NULL;
-    int ret = sqlite3_prepare_v2(db, query.c_str(), query.length() + 1, &stmt, &end);
-    if (ret != SQLITE_OK || !stmt || (end && *end))
+    if (prepare_v2(query, err) < 0)
         return -1;
 
-    ret = sqlite3_bind_blob(stmt, 1, file_last_modification.c_str(), file_last_modification.length(), SQLITE_STATIC);
+    int ret = sqlite3_bind_blob(stmt, 1, file_last_modification.c_str(), file_last_modification.length(), SQLITE_STATIC);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 2, generated_id);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 3, source_id);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 4, generated_time);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_blob(stmt, 5, generated_log.c_str(), generated_log.length(), SQLITE_STATIC);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_blob(stmt, 6, generated_error_log.c_str(), generated_error_log.length(), SQLITE_STATIC);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 7, file_id);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 8, user);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
+
+    ret = sqlite3_bind_blob(stmt, 9, options.c_str(), options.length(), SQLITE_STATIC);
+    if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
+        return -1;
+    }
 
     if (execute() < 0)
     {
@@ -276,7 +336,8 @@ long SQLLiteReport::update_file(int user, long file_id, const std::string& file_
     return file_id;
 }
 
-long SQLLiteReport::get_file_id(int user, const std::string& filename, const std::string& file_last_modification)
+long SQLLiteReport::get_file_id(int user, const std::string& filename, const std::string& file_last_modification,
+                                const std::string& options, std::string& err)
 {
     std::stringstream create;
     std::string key("ID");
@@ -285,39 +346,67 @@ long SQLLiteReport::get_file_id(int user, const std::string& filename, const std
     create << "SELECT " << key << " FROM MEDIACONCH_FILE";
     create << " WHERE FILENAME = ?";
     create << " AND USER = ?";
+    create << " AND OPTIONS = ?";
     if (file_last_modification.size())
         create << " AND FILE_LAST_MODIFICATION = ?";
     create << ";";
     query = create.str();
 
-    const char* end = NULL;
-    int ret = sqlite3_prepare_v2(db, query.c_str(), query.length() + 1, &stmt, &end);
-    if (ret != SQLITE_OK || !stmt || (end && *end))
+    if (prepare_v2(query, err) < 0)
         return -1;
 
-    ret = sqlite3_bind_blob(stmt, 1, filename.c_str(), filename.length(), SQLITE_STATIC);
+    int ret = sqlite3_bind_blob(stmt, 1, filename.c_str(), filename.length(), SQLITE_STATIC);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 2, user);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
+
+    std::string opt = options;
+    if (!opt.size())
+        opt = "";
+
+    ret = sqlite3_bind_blob(stmt, 3, opt.c_str(), opt.length(), SQLITE_STATIC);
+    if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
+        return -1;
+    }
 
     if (file_last_modification.size())
     {
-        ret = sqlite3_bind_blob(stmt, 3, file_last_modification.c_str(), file_last_modification.length(), SQLITE_STATIC);
+        ret = sqlite3_bind_blob(stmt, 4, file_last_modification.c_str(), file_last_modification.length(), SQLITE_STATIC);
         if (ret != SQLITE_OK)
+        {
+            err = get_sqlite_error(ret);
             return -1;
+        }
     }
 
-    if (execute() || !reports.size() || reports[0].find(key) == reports[0].end())
+    if (execute() < 0)
+    {
+        err = error;
         return -1;
+    }
+
+    if (!reports.size() || reports[0].find(key) == reports[0].end())
+    {
+        err = "Cannot find file ID.";
+        return -1;
+    }
 
     return std_string_to_int(reports[0][key]);
 }
 
 //---------------------------------------------------------------------------
-void SQLLiteReport::get_file_name_from_id(int user, long id, std::string& file)
+int SQLLiteReport::get_file_name_from_id(int user, long id, std::string& file, std::string& err)
 {
     std::stringstream create;
     std::string key("FILENAME");
@@ -327,29 +416,38 @@ void SQLLiteReport::get_file_name_from_id(int user, long id, std::string& file)
     create << " WHERE ID = ? AND USER = ?;";
     query = create.str();
 
-    const char* end = NULL;
-    int ret = sqlite3_prepare_v2(db, query.c_str(), query.length() + 1, &stmt, &end);
-    if (ret != SQLITE_OK || !stmt || (end && *end))
-        return;
+    if (prepare_v2(query, err) < 0)
+        return -1;
 
-    ret = sqlite3_bind_int(stmt, 1, id);
+    int ret = sqlite3_bind_int(stmt, 1, id);
     if (ret != SQLITE_OK)
-        return;
+    {
+        err = get_sqlite_error(ret);
+        return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 2, user);
     if (ret != SQLITE_OK)
-        return;
+    {
+        err = get_sqlite_error(ret);
+        return -1;
+    }
 
     if (execute() || !reports.size() || reports[0].find(key) == reports[0].end())
-        return;
+    {
+        err = error;
+        return -1;
+    }
 
     file = reports[0][key];
+    return 0;
 }
 
-void SQLLiteReport::get_file_information_from_id(int user, long id, std::string& filename, std::string& file_last_modification,
+int SQLLiteReport::get_file_information_from_id(int user, long id, std::string& filename, std::string& file_last_modification,
                                                  long& generated_id, long& source_id, size_t& generated_time,
-                                                 std::string& generated_log, std::string& generated_error_log, bool& analyzed,
-                                                 bool& has_error, std::string& error_log)
+                                                 std::string& generated_log, std::string& generated_error_log,
+                                                 std::string& options, bool& analyzed,
+                                                 bool& has_error, std::string& error_log, std::string& err)
 {
     std::stringstream create;
     std::string name("FILENAME");
@@ -360,6 +458,7 @@ void SQLLiteReport::get_file_information_from_id(int user, long id, std::string&
     std::string gen_time("GENERATED_TIME");
     std::string gen_log("GENERATED_LOG");
     std::string gen_error_log("GENERATED_ERROR_LOG");
+    std::string opt("OPTIONS");
     std::string has_err("HAS_ERROR");
     std::string err_log("ERROR_LOG");
 
@@ -372,27 +471,38 @@ void SQLLiteReport::get_file_information_from_id(int user, long id, std::string&
     create << ", " << gen_time;
     create << ", " << gen_log;
     create << ", " << gen_error_log;
+    create << ", " << opt;
     create << ", " << has_err;
     create << ", " << err_log;
     create << " FROM MEDIACONCH_FILE";
     create << " WHERE ID = ? AND USER = ?;";
     query = create.str();
 
-    const char* end = NULL;
-    int ret = sqlite3_prepare_v2(db, query.c_str(), query.length() + 1, &stmt, &end);
-    if (ret != SQLITE_OK || !stmt || (end && *end))
-        return;
+    if (prepare_v2(query, err) < 0)
+        return -1;
 
-    ret = sqlite3_bind_int(stmt, 1, id);
+    int ret = sqlite3_bind_int(stmt, 1, id);
     if (ret != SQLITE_OK)
-        return;
+    {
+        err = get_sqlite_error(ret);
+        return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 2, user);
     if (ret != SQLITE_OK)
-        return;
+    {
+        err = get_sqlite_error(ret);
+        return -1;
+    }
 
-    if (execute() || reports.size() != 1)
-        return;
+    if (execute())
+    {
+        err = error;
+        return -1;
+    }
+
+    if (reports.size() != 1)
+        return -1;
 
     if (reports[0].find(name) != reports[0].end())
         filename = reports[0][name];
@@ -418,14 +528,19 @@ void SQLLiteReport::get_file_information_from_id(int user, long id, std::string&
     if (reports[0].find(gen_error_log) != reports[0].end())
         generated_error_log = reports[0][gen_error_log];
 
+    if (reports[0].find(opt) != reports[0].end())
+        options = reports[0][opt];
+
     if (reports[0].find(has_err) != reports[0].end())
         has_error = (bool)std_string_to_int(reports[0][has_err]);
 
     if (reports[0].find(err_log) != reports[0].end())
         error_log = reports[0][err_log];
+
+    return 0;
 }
 
-int SQLLiteReport::update_file_generated_id(int user, long source_id, long generated_id)
+int SQLLiteReport::update_file_generated_id(int user, long source_id, long generated_id, std::string& err)
 {
     std::stringstream create;
 
@@ -435,27 +550,34 @@ int SQLLiteReport::update_file_generated_id(int user, long source_id, long gener
     create << "WHERE ID = ? AND USER = ?;";
     query = create.str();
 
-    const char* end = NULL;
-    int ret = sqlite3_prepare_v2(db, query.c_str(), query.length() + 1, &stmt, &end);
-    if (ret != SQLITE_OK || !stmt || (end && *end))
+    if (prepare_v2(query, err) < 0)
         return -1;
 
-    ret = sqlite3_bind_int(stmt, 1, generated_id);
+    int ret = sqlite3_bind_int(stmt, 1, generated_id);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 2, source_id);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 3, user);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     return execute();
 }
 
-int SQLLiteReport::update_file_analyzed(int user, long id, bool analyzed)
+int SQLLiteReport::update_file_analyzed(int user, long id, std::string& err, bool analyzed)
 {
     std::stringstream create;
 
@@ -465,27 +587,34 @@ int SQLLiteReport::update_file_analyzed(int user, long id, bool analyzed)
     create << "WHERE ID = ? AND USER = ?;";
     query = create.str();
 
-    const char* end = NULL;
-    int ret = sqlite3_prepare_v2(db, query.c_str(), query.length() + 1, &stmt, &end);
-    if (ret != SQLITE_OK || !stmt || (end && *end))
+    if (prepare_v2(query, err) < 0)
         return -1;
 
-    ret = sqlite3_bind_int(stmt, 1, analyzed);
+    int ret = sqlite3_bind_int(stmt, 1, analyzed);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 2, id);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 3, user);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     return execute();
 }
 
-int SQLLiteReport::update_file_error(int user, long id, bool has_error, const std::string& error_log)
+int SQLLiteReport::update_file_error(int user, long id, std::string& err, bool has_error, const std::string& error_log)
 {
     std::stringstream create;
 
@@ -495,31 +624,79 @@ int SQLLiteReport::update_file_error(int user, long id, bool has_error, const st
     create << "WHERE ID = ? AND USER = ?;";
     query = create.str();
 
-    const char* end = NULL;
-    int ret = sqlite3_prepare_v2(db, query.c_str(), query.length() + 1, &stmt, &end);
-    if (ret != SQLITE_OK || !stmt || (end && *end))
+    if (prepare_v2(query, err) < 0)
         return -1;
 
-    ret = sqlite3_bind_int(stmt, 1, has_error);
+    int ret = sqlite3_bind_int(stmt, 1, has_error);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_blob(stmt, 2, error_log.c_str(), error_log.length(), SQLITE_STATIC);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 3, id);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 4, user);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     return execute();
 }
 
-bool SQLLiteReport::file_is_analyzed(int user, long id)
+bool SQLLiteReport::file_id_match_user(int user, long id, std::string& err)
+{
+    std::stringstream create;
+
+    reports.clear();
+    create << "SELECT ID FROM MEDIACONCH_FILE ";
+    create << "WHERE ID = ? AND USER = ?;";
+    query = create.str();
+
+    if (prepare_v2(query, err) < 0)
+        return false;
+
+    int ret = sqlite3_bind_int(stmt, 1, id);
+    if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
+        return false;
+    }
+
+    ret = sqlite3_bind_int(stmt, 2, user);
+    if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
+        return false;
+    }
+
+    if (execute() < 0)
+    {
+        err = error;
+        return false;
+    }
+
+    if (reports.size() <= 0)
+        return false;
+
+    return true;
+}
+
+bool SQLLiteReport::file_is_analyzed(int user, long id, std::string& err)
 {
     std::stringstream create;
 
@@ -528,37 +705,46 @@ bool SQLLiteReport::file_is_analyzed(int user, long id)
     create << "WHERE ID = ? AND USER = ?;";
     query = create.str();
 
-    const char* end = NULL;
-    int ret = sqlite3_prepare_v2(db, query.c_str(), query.length() + 1, &stmt, &end);
-    if (ret != SQLITE_OK || !stmt || (end && *end))
+    if (prepare_v2(query, err) < 0)
         return false;
 
-    ret = sqlite3_bind_int(stmt, 1, id);
+    int ret = sqlite3_bind_int(stmt, 1, id);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return false;
+    }
 
     ret = sqlite3_bind_int(stmt, 2, user);
     if (ret != SQLITE_OK)
-        return -1;
-
-    if (execute() || reports.size() != 1)
+    {
+        err = get_sqlite_error(ret);
         return false;
+    }
 
-    bool analyzed = false;
-    if (reports[0].find("ANALYZED") != reports[0].end())
-        analyzed = (bool)std_string_to_int(reports[0]["ANALYZED"]);
+    if (execute() || reports.size() <= 0)
+    {
+        err = error;
+        return false;
+    }
 
-    return analyzed;
+    return true;
 }
 
 int SQLLiteReport::save_report(int user, long file_id, MediaConchLib::report reportKind, MediaConchLib::format format,
                                const std::string& report, MediaConchLib::compression compress,
-                               int mil_version)
+                               int mil_version, std::string& err)
 {
     std::stringstream create;
 
-    if (report_is_registered(user, file_id, reportKind, format))
-        return update_report(user, file_id, reportKind, format, report, compress, mil_version);
+    if (!file_id_match_user(user, file_id, err))
+    {
+        err = "File ID is not matching the user.";
+        return -1;
+    }
+
+    if (report_is_registered(user, file_id, reportKind, format, err))
+        return update_report(user, file_id, reportKind, format, report, compress, mil_version, err);
 
     reports.clear();
     create << "INSERT INTO MEDIACONCH_REPORT";
@@ -566,41 +752,57 @@ int SQLLiteReport::save_report(int user, long file_id, MediaConchLib::report rep
     create << " VALUES (?, ?, ?, ?, ?, ?);";
     query = create.str();
 
-    const char* end = NULL;
-    int ret = sqlite3_prepare_v2(db, query.c_str(), query.length() + 1, &stmt, &end);
-    if (ret != SQLITE_OK || !stmt || (end && *end))
+    if (prepare_v2(query, err) < 0)
         return -1;
 
-    ret = sqlite3_bind_int(stmt, 1, file_id);
+    int ret = sqlite3_bind_int(stmt, 1, file_id);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 2, (int)reportKind);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 3, (int)format);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_blob(stmt, 4, report.c_str(), report.length(), SQLITE_STATIC);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 5, (int)compress);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 6, mil_version);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     return execute();
 }
 
-int SQLLiteReport::update_report(int user, long file_id, MediaConchLib::report reportKind, MediaConchLib::format format,
+int SQLLiteReport::update_report(int, long file_id, MediaConchLib::report reportKind, MediaConchLib::format format,
                                  const std::string& report, MediaConchLib::compression compress,
-                                 int mil_version)
+                                 int mil_version, std::string& err)
 {
     std::stringstream create;
 
@@ -610,60 +812,89 @@ int SQLLiteReport::update_report(int user, long file_id, MediaConchLib::report r
     create << "WHERE FILE_ID = ? AND TOOL = ? AND FORMAT = ?;";
     query = create.str();
 
-    const char* end = NULL;
-    int ret = sqlite3_prepare_v2(db, query.c_str(), query.length() + 1, &stmt, &end);
-    if (ret != SQLITE_OK || !stmt || (end && *end))
+    if (prepare_v2(query, err) < 0)
         return -1;
 
-    ret = sqlite3_bind_blob(stmt, 1, report.c_str(), report.length(), SQLITE_STATIC);
+    int ret = sqlite3_bind_blob(stmt, 1, report.c_str(), report.length(), SQLITE_STATIC);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 2, (int)compress);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 3, mil_version);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 4, file_id);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 5, (int)reportKind);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     ret = sqlite3_bind_int(stmt, 6, (int)format);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     return execute();
 }
 
-int SQLLiteReport::remove_report(int user, long file_id)
+int SQLLiteReport::remove_report(int user, long file_id, std::string& err)
 {
+    if (!file_id_match_user(user, file_id, err))
+    {
+        err = "File ID is not matching the user.";
+        return -1;
+    }
+
     std::stringstream delete_query;
 
     reports.clear();
     query = "DELETE FROM MEDIACONCH_REPORT WHERE FILE_ID = ?;";
 
-    const char* end = NULL;
-    int ret = sqlite3_prepare_v2(db, query.c_str(), query.length() + 1, &stmt, &end);
-    if (ret != SQLITE_OK || !stmt || (end && *end))
+    if (prepare_v2(query, err) < 0)
         return -1;
 
-    ret = sqlite3_bind_int(stmt, 1, file_id);
+    int ret = sqlite3_bind_int(stmt, 1, file_id);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
     return execute();
 }
 
 void SQLLiteReport::get_report(int user, long file_id, MediaConchLib::report reportKind, MediaConchLib::format format,
-                               std::string& report, MediaConchLib::compression& compress)
+                               std::string& report, MediaConchLib::compression& compress, std::string& err)
 {
+    if (!file_id_match_user(user, file_id, err))
+    {
+        err = "File ID is not matching the user.";
+        return;
+    }
+
     std::stringstream create;
 
     reports.clear();
@@ -673,30 +904,43 @@ void SQLLiteReport::get_report(int user, long file_id, MediaConchLib::report rep
     create << "AND FORMAT = ?;";
     query = create.str();
 
-    const char* end = NULL;
-    int ret = sqlite3_prepare_v2(db, query.c_str(), query.length() + 1, &stmt, &end);
-    if (ret != SQLITE_OK || !stmt || (end && *end))
+    if (prepare_v2(query, err) < 0)
         return;
 
-    ret = sqlite3_bind_int(stmt, 1, file_id);
+    int ret = sqlite3_bind_int(stmt, 1, file_id);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return;
+    }
 
     ret = sqlite3_bind_int(stmt, 2, (int)reportKind);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return;
+    }
 
     ret = sqlite3_bind_int(stmt, 3, (int)format);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return;
+    }
 
     if (execute() < 0 || !reports.size())
+    {
+        err = error;
         return;
+    }
 
     std::map<std::string, std::string> r = reports[0];
 
     if (r.find("REPORT") == r.end())
+    {
+        err = "No report found";
         return;
+    }
     report += r["REPORT"];
 
     if (r.find("COMPRESS") != r.end())
@@ -711,8 +955,15 @@ void SQLLiteReport::get_report(int user, long file_id, MediaConchLib::report rep
     }
 }
 
-bool SQLLiteReport::report_is_registered(int user, long file_id, MediaConchLib::report reportKind, MediaConchLib::format format)
+bool SQLLiteReport::report_is_registered(int user, long file_id, MediaConchLib::report reportKind,
+                                         MediaConchLib::format format, std::string& err)
 {
+    if (!file_id_match_user(user, file_id, err))
+    {
+        err = "File ID is not matching the user.";
+        return false;
+    }
+
     std::stringstream create;
     std::string key("COUNT(REPORT)");
 
@@ -723,24 +974,37 @@ bool SQLLiteReport::report_is_registered(int user, long file_id, MediaConchLib::
     create << "AND FORMAT = ?;";
     query = create.str();
 
-    const char* end = NULL;
-    int ret = sqlite3_prepare_v2(db, query.c_str(), query.length() + 1, &stmt, &end);
-    if (ret != SQLITE_OK || !stmt || (end && *end))
+    if (prepare_v2(query, err) < 0)
         return false;
 
-    ret = sqlite3_bind_int(stmt, 1, file_id);
+    int ret = sqlite3_bind_int(stmt, 1, file_id);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return false;
+    }
 
     ret = sqlite3_bind_int(stmt, 2, (int)reportKind);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return false;
+    }
 
     ret = sqlite3_bind_int(stmt, 3, (int)format);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return false;
+    }
 
-    if (execute() || !reports.size() || reports[0].find(key) == reports[0].end())
+    if (execute())
+    {
+        err = error;
+        return false;
+    }
+
+    if (!reports.size() || reports[0].find(key) == reports[0].end())
         return false;
 
     if (reports[0][key] == "0")
@@ -749,8 +1013,14 @@ bool SQLLiteReport::report_is_registered(int user, long file_id, MediaConchLib::
     return true;
 }
 
-int SQLLiteReport::version_registered(int user, long file_id)
+int SQLLiteReport::version_registered(int user, long file_id, std::string& err)
 {
+    if (!file_id_match_user(user, file_id, err))
+    {
+        err = "File ID is not matching the user.";
+        return -1;
+    }
+
     std::stringstream create;
     std::string key("MIL_VERSION");
 
@@ -759,22 +1029,31 @@ int SQLLiteReport::version_registered(int user, long file_id)
     create << "FILE_ID = ?;";
     query = create.str();
 
-    const char* end = NULL;
-    int ret = sqlite3_prepare_v2(db, query.c_str(), query.length() + 1, &stmt, &end);
-    if (ret != SQLITE_OK || !stmt || (end && *end))
+    if (prepare_v2(query, err) < 0)
         return -1;
 
-    ret = sqlite3_bind_int(stmt, 1, file_id);
+    int ret = sqlite3_bind_int(stmt, 1, file_id);
     if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
         return -1;
+    }
 
-    if (execute() || !reports.size() || reports[0].find(key) == reports[0].end())
+    if (execute())
+    {
+        err = error;
         return -1;
+    }
+
+    if (!reports.size() || reports[0].find(key) == reports[0].end())
+    {
+        return -1;
+    }
 
     return std_string_to_int(reports[0][key]);
 }
 
-void SQLLiteReport::get_elements(int user, std::vector<std::string>& vec)
+int SQLLiteReport::get_elements(int user, std::vector<std::string>& vec, std::string& err)
 {
     std::stringstream create;
     std::string key("FILENAME");
@@ -783,43 +1062,96 @@ void SQLLiteReport::get_elements(int user, std::vector<std::string>& vec)
     create << "SELECT " << key << " FROM MEDIACONCH_FILE WHERE USER = ?;";
     query = create.str();
 
-    const char* end = NULL;
-    int ret = sqlite3_prepare_v2(db, query.c_str(), query.length() + 1, &stmt, &end);
-    if (ret != SQLITE_OK || !stmt || (end && *end))
-        return;
+    if (prepare_v2(query, err) < 0)
+        return -1;
 
-    ret = sqlite3_bind_int(stmt, 1, user);
+    int ret = sqlite3_bind_int(stmt, 1, user);
     if (ret != SQLITE_OK)
-        return;
+    {
+        err = get_sqlite_error(ret);
+        return -1;
+    }
 
     if (execute() || !reports.size())
-        return;
+    {
+        err = get_sqlite_error(ret);
+        return -1;
+    }
 
     for (size_t i = 0; i < reports.size(); ++i)
     {
         if (reports[i].find(key) != reports[i].end())
             vec.push_back(reports[i][key]);
     }
+
+    return 0;
+}
+
+int SQLLiteReport::get_elements(int user, std::vector<long>& vec, std::string& err)
+{
+    std::stringstream create;
+    std::string key("ID");
+
+    reports.clear();
+    create << "SELECT " << key << " FROM MEDIACONCH_FILE WHERE USER = ?;";
+    query = create.str();
+
+    if (prepare_v2(query, err) < 0)
+        return -1;
+
+    int ret = sqlite3_bind_int(stmt, 1, user);
+    if (ret != SQLITE_OK)
+    {
+        err = get_sqlite_error(ret);
+        return -1;
+    }
+
+    if (execute() || !reports.size())
+    {
+        err = get_sqlite_error(ret);
+        return -1;
+    }
+
+    for (size_t i = 0; i < reports.size(); ++i)
+    {
+        if (reports[i].find(key) != reports[i].end())
+            vec.push_back((long)std_string_to_int(reports[i][key]));
+    }
+
+    return 0;
 }
 
 //---------------------------------------------------------------------------
-void SQLLiteReport::get_element_report_kind(int user, long file_id, MediaConchLib::report& report_kind)
+int SQLLiteReport::get_element_report_kind(int user, long file_id, MediaConchLib::report& report_kind, std::string& err)
 {
+    if (!file_id_match_user(user, file_id, err))
+    {
+        err = "File ID is not matching the user.";
+        return -1;
+    }
+
     report_kind = MediaConchLib::report_MediaConch;
     reports.clear();
     query = "SELECT TOOL FROM MEDIACONCH_REPORT WHERE FILE_ID = ?;";
 
-    const char* end = NULL;
-    int ret = sqlite3_prepare_v2(db, query.c_str(), query.length() + 1, &stmt, &end);
-    if (ret != SQLITE_OK || !stmt || (end && *end))
-        return;
+    if (prepare_v2(query, err) < 0)
+        return -1;
 
-    ret = sqlite3_bind_int(stmt, 1, file_id);
+    int ret = sqlite3_bind_int(stmt, 1, file_id);
     if (ret != SQLITE_OK)
-        return;
+    {
+        err = get_sqlite_error(ret);
+        return -1;
+    }
 
-    if (execute() || !reports.size())
-        return;
+    if (execute())
+    {
+        err = error;
+        return -1;
+    }
+
+    if (!reports.size())
+        return 0;
 
     for (size_t i = 0; i < reports.size(); ++i)
     {
@@ -832,6 +1164,8 @@ void SQLLiteReport::get_element_report_kind(int user, long file_id, MediaConchLi
             report_kind = tool_i;
         }
     }
+
+    return 0;
 }
 
 }
