@@ -21,7 +21,7 @@
 #include "DpfManager.h"
 #include "PluginLog.h"
 #include "PluginFileLog.h"
-#include "FFmpeg.h"
+#include "PluginPreHook.h"
 #include <ZenLib/Ztring.h>
 
 #if defined(_WIN32) || defined(WIN32)
@@ -129,7 +129,7 @@ namespace MediaConch {
         return size == 0;
     }
 
-    void Scheduler::get_elements(int user, std::vector<std::string>& vec)
+    int Scheduler::get_elements(int user, std::vector<std::string>& vec, std::string&)
     {
         CS.Enter();
         std::map<QueueElement*, QueueElement*>::iterator it = working.begin();
@@ -137,6 +137,20 @@ namespace MediaConch {
             if (it->first && it->first->user == user)
                 vec.push_back(it->first->filename);
         CS.Leave();
+
+        return 0;
+    }
+
+    int Scheduler::get_elements(int user, std::vector<long>& vec, std::string&)
+    {
+        CS.Enter();
+        std::map<QueueElement*, QueueElement*>::iterator it = working.begin();
+        for (; it != working.end(); ++it)
+            if (it->first && it->first->user == user)
+                vec.push_back(it->first->file_id);
+        CS.Leave();
+
+        return 0;
     }
 
     bool Scheduler::element_is_finished(int user, long file_id, double& percent_done)
@@ -166,7 +180,8 @@ namespace MediaConch {
         return ret;
     }
 
-    long Scheduler::element_exists(int user, const std::string& filename)
+    long Scheduler::element_exists(int user, const std::string& filename,
+                                   const std::string& options, std::string& err)
     {
         CS.Enter();
         long file_id = queue->has_element(user, filename);
@@ -178,12 +193,15 @@ namespace MediaConch {
 
         std::map<QueueElement*, QueueElement*>::iterator it = working.begin();
         for (; it != working.end(); ++it)
-            if (it->first->filename == filename && user == it->first->user)
+            if (it->first->filename == filename && user == it->first->user && options == it->first->options_str)
                 break;
 
         if (it != working.end())
             file_id = it->first->file_id;
         CS.Leave();
+
+        if (file_id == -1)
+            err = "File not in scheduler.";
         return file_id;
     }
 
@@ -251,8 +269,8 @@ namespace MediaConch {
                 continue;
 
             Plugin *p = NULL;
-            if (plugins[i]->get_name() == "FFmpeg")
-                p = new FFmpeg(*(FFmpeg*)plugins[i]);
+            if (plugins[i]->get_name() == "PreHook")
+                p = new PluginPreHook(*(PluginPreHook*)plugins[i]);
             else if (plugins[i]->get_name() == "FileLog")
                 p = new PluginFileLog(*(PluginFileLog*)plugins[i]);
             else
@@ -286,21 +304,21 @@ namespace MediaConch {
                 new_file = ((PluginPreHook*)p)->get_output_file();
 
                 std::vector<std::pair<std::string,std::string> > options;
-                std::map<std::string, std::string>::iterator it = el->options.begin();
-                for (; it != el->options.end(); ++it)
-                    options.push_back(std::make_pair(it->first, it->second));
+                for (size_t i = 0; i < el->options.size(); ++i)
+                    options.push_back(std::make_pair(el->options[i].first, el->options[i].second));
 
                 std::vector<std::string> plugins;
+                std::string err;
                 long id = core->checker_analyze(el->user, new_file, old_id, time_passed, generated_log,
-                                                generated_error_log, options, plugins, el->mil_analyze);
+                                                generated_error_log, options, plugins, err, el->mil_analyze);
                 if (id >= 0)
-                    core->file_update_generated_file(el->user, old_id, id);
+                    core->file_update_generated_file(el->user, old_id, id, err);
                 old_id = id;
             }
             else if (ret)
             {
                 std::string error_log = ((PluginPreHook*)p)->get_report_err();
-                core->update_file_error(el->user, old_id, true, error_log);
+                core->update_file_error(el->user, old_id, true, error_log, err);
                 delete p;
                 return ret;
             }
