@@ -56,10 +56,12 @@ public:
                               const std::vector<std::string>& plugins, bool mil_analyze);
     void work_finished(QueueElement* el, MediaInfoNameSpace::MediaInfo* MI);
     bool is_finished();
-    long element_exists(int user, const std::string& filename);
+    long element_exists(int user, const std::string& filename,
+                        const std::string& options, std::string& err);
     bool element_is_finished(int user, long file_id, double& percent_done);
     void set_max_threads(size_t nb) { max_threads = nb; }
-    void get_elements(int user, std::vector<std::string>& vec);
+    int  get_elements(int user, std::vector<std::string>& vec, std::string& err);
+    int  get_elements(int user, std::vector<long>& vec, std::string& err);
     int  another_work_to_do(QueueElement* el, MediaInfoNameSpace::MediaInfo* MI);
     int  execute_pre_hook_plugins(QueueElement *el, std::string& err, bool& analyze_file);
     void write_log_timestamp(int level, std::string log);
