@@ -170,4 +170,13 @@ void DatabaseUi::get_sql_query_for_update_ui_settings_table_v8(std::string& q)
     q = create.str();
 }
 
+//---------------------------------------------------------------------------
+void DatabaseUi::get_sql_query_for_update_ui_settings_table_v9(std::string& q)
+{
+    std::stringstream create;
+    create << "ALTER TABLE UI_SETTINGS"; // Table name
+    create << " ADD MCO_TOKEN    TEXT DEFAULT NULL;";
+    q = create.str();
+}
+
 }
