@@ -99,6 +99,9 @@ public:
     virtual int ui_settings_save_last_save_display_path(const std::string&, int user_id = -1) = 0;
     virtual int ui_settings_get_last_save_display_path(std::string&, int user_id = -1) = 0;
 
+    virtual int ui_settings_save_mco_token(const std::string&, int user_id = -1) = 0;
+    virtual int ui_settings_get_mco_token(std::string&, int user_id = -1) = 0;
+
 protected:
     //Database dependant
     void        get_sql_query_for_create_ui_table(std::string& q);
@@ -112,6 +115,7 @@ protected:
     void        get_sql_query_for_update_ui_settings_table_v6(std::string& q);
     void        get_sql_query_for_update_ui_settings_table_v7(std::string& q);
     void        get_sql_query_for_update_ui_settings_table_v8(std::string& q);
+    void        get_sql_query_for_update_ui_settings_table_v9(std::string& q);
 
 private:
     DatabaseUi (const DatabaseUi&);
