@@ -83,6 +83,9 @@ public:
     virtual int ui_settings_save_last_save_display_path(const std::string&, int user_id = -1);
     virtual int ui_settings_get_last_save_display_path(std::string&, int user_id = -1);
 
+    virtual int  ui_settings_save_mco_token(const std::string&, int user_id=-1);
+    virtual int  ui_settings_get_mco_token(std::string&, int user_id = -1);
+
     // UI
     virtual int ui_add_file(const FileRegistered* file);
     virtual int ui_add_files(const std::vector<FileRegistered*>& files);
