@@ -10,28 +10,35 @@
 #include <Common/XsltPolicy.h>
 
 #include <QDir>
+#include <QTimer>
 #include <QFileDialog>
 #include <QTextStream>
 #include <QDesktopServices>
 
-namespace MediaConch {
-
+namespace MediaConch
+{
     void WebCommonPage::menu_link_checker(const QString& name)
     {
-        if (!name.compare("Checker"))
-            mainwindow->checker_selected();
-        else if (!name.compare("Policies"))
-            mainwindow->policies_selected();
-        else if (!name.compare("Public Policies"))
-            mainwindow->public_policies_selected();
-        else if (!name.compare("Display"))
-            mainwindow->display_selected();
-        else if (!name.compare("Settings"))
-            mainwindow->settings_selected();
-        else if (!name.compare("Help"))
-            mainwindow->on_actionGettingStarted_triggered();
+        menu_name = name;
+        QTimer::singleShot(0, this, SLOT(timer_menu_link()));
+    }
+
+    void WebCommonPage::timer_menu_link()
+    {
+        if (!menu_name.compare("Checker"))
+            mainwindow->on_actionChecker_triggered();
+        else if (!menu_name.compare("Policies"))
+            Q_EMIT mainwindow->on_actionPolicies_triggered();
+        else if (!menu_name.compare("Public Policies"))
+            Q_EMIT mainwindow->on_actionPublicPolicies_triggered();
+        else if (!menu_name.compare("Display"))
+            Q_EMIT mainwindow->on_actionDisplay_triggered();
+        else if (!menu_name.compare("Settings"))
+            Q_EMIT mainwindow->on_actionSettings_triggered();
+        else if (!menu_name.compare("Help"))
+            Q_EMIT mainwindow->on_actionGettingStarted_triggered();
         else
-            mainwindow->checker_selected();
+            mainwindow->on_actionChecker_triggered();
     }
 
     void WebCommonPage::on_input_changed(const QString& inputName)
@@ -92,7 +99,8 @@ namespace MediaConch {
             verbosity_p = &verbosity_i;
         }
 
-        mainwindow->get_implementation_report(file_id, report, &display_i, verbosity_p);
+        std::string err;
+        mainwindow->get_implementation_report(file_id, report, err, &display_i, verbosity_p);
         return report;
     }
 
@@ -107,7 +115,9 @@ namespace MediaConch {
             verbosity_i = verbosity.toInt();
             verbosity_p = &verbosity_i;
         }
-        mainwindow->get_implementation_report(file_id, report, &display_i, verbosity_p);
+
+        std::string err;
+        mainwindow->get_implementation_report(file_id, report, err, &display_i, verbosity_p);
         on_download_report(report, file_id, "ImplementationReport");
     }
 
@@ -118,7 +128,8 @@ namespace MediaConch {
         if (policy_i != -1)
         {
             int display_i = display.toInt();
-            mainwindow->validate_policy(file_id, report, policy_i, &display_i);
+            std::string err;
+            mainwindow->validate_policy(file_id, report, err, policy_i, &display_i);
         }
         return report;
     }
@@ -128,38 +139,45 @@ namespace MediaConch {
         QString report;
         int policy_i = policy.toInt();
         int display_i = display.toInt();
-        mainwindow->validate_policy(file_id, report, policy_i, &display_i);
+        std::string err;
+        mainwindow->validate_policy(file_id, report, err, policy_i, &display_i);
         on_download_report(report, file_id, "MediaConchReport");
     }
 
     QString WebCommonPage::on_fill_mediainfo_report(long file_id)
     {
-        return mainwindow->get_mediainfo_jstree(file_id);
+        std::string err;
+        return mainwindow->get_mediainfo_jstree(file_id, err);
     }
 
     void WebCommonPage::on_save_mediainfo_report(long file_id)
     {
         std::string display_name, display_content;
-        QString report = mainwindow->get_mediainfo_xml(file_id, display_name, display_content);
+        std::string err;
+        QString report = mainwindow->get_mediainfo_xml(file_id, display_name, display_content, err);
         on_download_report(report, file_id, "MediaInfo");
     }
 
     QString WebCommonPage::on_fill_mediatrace_report(long file_id)
     {
-        return mainwindow->get_mediatrace_jstree(file_id);
+        std::string err;
+        return mainwindow->get_mediatrace_jstree(file_id, err);
     }
 
     void WebCommonPage::on_save_mediatrace_report(long file_id)
     {
         std::string display_name, display_content;
-        QString report = mainwindow->get_mediatrace_xml(file_id, display_name, display_content);
+        std::string err;
+        QString report = mainwindow->get_mediatrace_xml(file_id, display_name, display_content, err);
         on_download_report(report, file_id, "MediaTrace");
     }
 
     QString WebCommonPage::on_create_policy_from_file(long file_id)
     {
-        int id = mainwindow->xslt_policy_create_from_file(file_id);
-        std::string n, err;
+        std::string n;
+        QString err;
+
+        int id = mainwindow->xslt_policy_create_from_file(file_id, err);
         if (mainwindow->policy_get_name(id, n, err) < 0)
             n = std::string();
         QString name = QString().fromUtf8(n.c_str(), n.length());
@@ -170,54 +188,71 @@ namespace MediaConch {
         return script;
     }
 
-    void WebCommonPage::on_file_upload_selected(const QString& policy, const QString& display,
+    QString WebCommonPage::on_file_upload_selected(const QString& policy, const QString& display,
                                                 const QString& verbosity, bool fixer)
     {
         QStringList files = file_selector.value("checkerUpload_file", QStringList());
 
         if (!files.size())
-            return;
+            return QString();
 
         for (int i = 0; i < files.size(); ++i)
         {
             QFileInfo f = QFileInfo(files[i]);
-            mainwindow->add_file_to_list(f.fileName(), f.absolutePath(), policy, display, verbosity, fixer);
+            std::string error;
+            if (mainwindow->add_file_to_list(f.fileName(), f.absolutePath(), policy,
+                                             display, verbosity, fixer, error) < 0)
+                return QString("%1\n").arg(QString().fromUtf8(error.c_str(), error.size()));
         }
         file_selector.clear();
         clean_forms();
         use_javascript(QString("startWaitingLoop()"));
+
+        return QString();
     }
 
-    void WebCommonPage::on_file_online_selected(const QString& url, const QString& policy,
-                                          const QString& display, const QString& verbosity, bool fixer)
+    QString WebCommonPage::on_file_online_selected(const QString& url, const QString& policy,
+                                                   const QString& display, const QString& verbosity,
+                                                   bool fixer)
     {
+        QString ret;
         if (!url.length())
-            return;
+            return ret;
 
-        mainwindow->add_file_to_list(url, "", policy, display, verbosity, fixer);
+        std::string error;
+        if (mainwindow->add_file_to_list(url, "", policy, display, verbosity, fixer, error) < 0)
+            ret += QString("%1\n").arg(QString().fromUtf8(error.c_str(), error.size()));
         file_selector.clear();
         clean_forms();
         use_javascript(QString("startWaitingLoop()"));
-    }
+        return ret;    }
 
-    void WebCommonPage::on_file_repository_selected(const QString& policy, const QString& display,
+    QString WebCommonPage::on_file_repository_selected(const QString& policy, const QString& display,
                                                     const QString& verbosity, bool fixer)
     {
+        QString ret;
         QStringList dirname = file_selector.value("checkerRepository_directory", QStringList());
         if (dirname.empty())
-            return;
+            return ret;
 
         QDir dir(dirname.last());
         QFileInfoList list;
         add_sub_directory_files_to_list(dir, list);
         if (!list.count())
-            return;
+            return ret;
 
         for (int i = 0; i < list.size(); ++i)
-            mainwindow->add_file_to_list(list[i].fileName(), list[i].absolutePath(), policy, display, verbosity, fixer);
+        {
+            std::string error;
+            if (mainwindow->add_file_to_list(list[i].fileName(), list[i].absolutePath(), policy,
+                                             display, verbosity, fixer, error))
+                ret += QString("%1\n").arg(QString().fromUtf8(error.c_str(), error.size()));
+        }
         file_selector.clear();
         clean_forms();
         use_javascript(QString("startWaitingLoop()"));
+
+        return ret;
     }
 
     void WebCommonPage::on_save_settings_selected(const QString& policy,
@@ -494,10 +529,12 @@ namespace MediaConch {
             mainwindow->set_last_load_files_path(info.absolutePath().toUtf8().data());
         }
 
-        on_file_upload_selected(QString().setNum(mainwindow->select_correct_policy()),
-                                QString().setNum(mainwindow->select_correct_display()),
-                                QString().setNum(mainwindow->select_correct_verbosity()),
-                                false);
+        QString err = on_file_upload_selected(QString().setNum(mainwindow->select_correct_policy()),
+                                              QString().setNum(mainwindow->select_correct_display()),
+                                              QString().setNum(mainwindow->select_correct_verbosity()),
+                                              false);
+        if (err.size())
+            mainwindow->set_str_msg_to_status_bar(err.toUtf8().data());
     }
 
     //---------------------------------------------------------------------------
@@ -569,6 +606,7 @@ namespace MediaConch {
     QString WebCommonPage::policy_is_valid(long file_id)
     {
         //{"valid":false,"fileId":"fileId","error":null}
+        std::string err;
         QString json = QString("{\"fileId\":\"%1\",").arg(file_id);
         FileRegistered* fr = mainwindow->get_file_registered_from_id(file_id);
         if (!fr)
@@ -588,7 +626,15 @@ namespace MediaConch {
 
         bool policy_valid = false;
         std::vector<MediaConchLib::Checker_ValidateRes*> res;
-        if (mainwindow->validate_policy(file_id, fr->policy, res) == 0 && res.size() == 1)
+        if (mainwindow->validate_policy(file_id, fr->policy, res, err) < 0)
+        {
+            json += QString("\"valid\":false,\"error\":\"%2\"}")
+                .arg(QString().fromUtf8(err.c_str(), err.size()));
+            delete fr;
+            return json;
+        }
+
+        if (res.size() == 1)
             policy_valid = res[0]->valid;
 
         for (size_t j = 0; j < res.size() ; ++j)
@@ -799,8 +845,15 @@ namespace MediaConch {
     {
         MediaConchLib::Get_Policies policies;
         QString res;
+        QString err;
+
+        if (mainwindow->get_policies("JSTREE", policies, err) < 0)
+        {
+            string_to_json(err);
+            res = "{\"error\":\"" + err + "\"}";
+            return res;
+        }
 
-        mainwindow->get_policies("JSTREE", policies);
         if (policies.format != "JSTREE")
         {
             res = "{\"error\":\"Cannot generate the policies tree\"}";
@@ -813,13 +866,36 @@ namespace MediaConch {
 
     QString WebCommonPage::policy_get_xml(int id)
     {
-        std::string policy, err;
-        if (mainwindow->policy_dump(id, policy, err))
-            return QString().fromUtf8(err.c_str());
+        std::string policy;
+        QString err;
+        if (mainwindow->policy_dump(id, policy, err) < 0)
+            return err;
 
         return QString().fromUtf8(policy.c_str());
     }
 
+    QString WebCommonPage::policy_get_jstree(int id)
+    {
+        QString json;
+        QString err;
+
+        MediaConchLib::Get_Policy p;
+        if (mainwindow->policy_get(id, "JSTREE", p, err) < 0)
+        {
+            json = QString("{\"error\":\"") + err + "\"}";
+            return json;
+        }
+
+        if (p.format != "JSTREE")
+        {
+            json = "{\"error\":\"Cannot generate the policy\"}";
+            return json;
+        }
+
+        json = QString().fromUtf8(p.jstree->c_str(), p.jstree->length());
+        return json;
+    }
+
     QString WebCommonPage::import_policy()
     {
         QString file;
@@ -839,24 +915,22 @@ namespace MediaConch {
     {
 
         QString json;
-        std::string err;
+        QString err;
         int id;
         if ((id = mainwindow->policy_import(file, err)) < 0)
         {
-            QString error = QString().fromUtf8(err.c_str(), err.length());
-            if (!error.size())
-                mainwindow->get_error_http((MediaConchLib::errorHttp)id, error);
-            string_to_json(error);
-            json = QString("{\"error\":\"%1\"}").arg(error);
+            string_to_json(err);
+            json = QString("{\"error\":\"%1\"}").arg(err);
             return json;
         }
 
         mainwindow->policy_save(id, err);
 
         MediaConchLib::Get_Policy p;
-        if (mainwindow->policy_get(id, "JSTREE", p) < 0)
+        if (mainwindow->policy_get(id, "JSTREE", p, err) < 0)
         {
-            json = "{\"error\":\"Cannot import the policy\"}";
+            string_to_json(err);
+            json = QString("{\"error\":\"") + err + "\"}";
             return json;
         }
 
@@ -874,21 +948,19 @@ namespace MediaConch {
     {
 
         QString json;
-        std::string err;
+        QString err;
         int id;
         if ((id = mainwindow->policy_import_data(data, err)) < 0)
         {
-            QString error = QString().fromUtf8(err.c_str(), err.length());
-            if (!error.size())
-                mainwindow->get_error_http((MediaConchLib::errorHttp)id, error);
-            string_to_json(error);
-            json = QString("{\"error\":\"%1\"}").arg(error);
+            string_to_json(err);
+            json = QString("{\"error\":\"%1\"}").arg(err);
             return json;
         }
 
         mainwindow->policy_save(id, err);
 
-        json = "{}";
+        json = QString("{\"policyId\":%1}").arg(id);
+
         return json;
     }
 
@@ -913,25 +985,22 @@ namespace MediaConch {
     QString WebCommonPage::xslt_policy_create(int parent_id)
     {
         QString json;
-        std::string err;
+        QString err;
 
         int id;
         if ((id = mainwindow->xslt_policy_create(parent_id, err)) < 0)
         {
-            QString error = QString().fromUtf8(err.c_str(), err.length());
-            if (!error.size())
-                mainwindow->get_error_http((MediaConchLib::errorHttp)id, error);
-            string_to_json(error);
-            json = QString("{\"error\":\"%1\"}").arg(error);
+            string_to_json(err);
+            json = QString("{\"error\":\"%1\"}").arg(err);
             return json;
         }
 
         mainwindow->policy_save(id, err);
 
         MediaConchLib::Get_Policy p;
-        if (mainwindow->policy_get(id, "JSTREE", p) < 0)
+        if (mainwindow->policy_get(id, "JSTREE", p, err) < 0)
         {
-            json = "{\"error\":\"Cannot create the policy\"}";
+            json = QString("{\"error\":\"") + err + "\"}";
             return json;
         }
 
@@ -948,24 +1017,21 @@ namespace MediaConch {
     QString WebCommonPage::policy_duplicate(int id, int dst_policy_id)
     {
         QString json;
-        std::string err;
+        QString err;
         int ret = -1;
 
         if ((ret = mainwindow->policy_duplicate(id, dst_policy_id, err)) < 0)
         {
-            QString error = QString().fromUtf8(err.c_str(), err.length());
-            if (!error.size())
-                mainwindow->get_error_http((MediaConchLib::errorHttp)ret, error);
-            string_to_json(error);
-            json = QString("{\"error\":\"%1\"}").arg(error);
+            string_to_json(err);
+            json = QString("{\"error\":\"%1\"}").arg(err);
             return json;
         }
         mainwindow->policy_save(ret, err);
 
         MediaConchLib::Get_Policy p;
-        if (mainwindow->policy_get(ret, "JSTREE", p) < 0)
+        if (mainwindow->policy_get(ret, "JSTREE", p, err) < 0)
         {
-            json = "{\"error\":\"Cannot duplicate the policy\"}";
+            json = QString("{\"error\":\"") + err + "\"}";
             return json;
         }
 
@@ -982,25 +1048,23 @@ namespace MediaConch {
     QString WebCommonPage::policy_move(int id, int dst_policy_id)
     {
         QString json;
-        std::string err;
+        QString err;
         int ret = -1;
 
         if ((ret = mainwindow->policy_move(id, dst_policy_id, err)) < 0)
         {
-            QString error = QString().fromUtf8(err.c_str(), err.length());
-            if (!error.size())
-                mainwindow->get_error_http((MediaConchLib::errorHttp)ret, error);
-            string_to_json(error);
-            json = QString("{\"error\":\"%1\"}").arg(error);
+            string_to_json(err);
+            json = QString("{\"error\":\"%1\"}").arg(err);
             return json;
         }
 
         mainwindow->policy_save(ret, err);
 
         MediaConchLib::Get_Policy p;
-        if (mainwindow->policy_get(ret, "JSTREE", p) < 0)
+        if (mainwindow->policy_get(ret, "JSTREE", p, err) < 0)
         {
-            json = "{\"error\":\"Cannot move the policy\"}";
+            string_to_json(err);
+            json = QString("{\"error\":\"") + err + "\"}";
             return json;
         }
 
@@ -1019,15 +1083,12 @@ namespace MediaConch {
         //return:
         QString json;
 
-        std::string err;
+        QString err;
         int code;
         if ((code = mainwindow->policy_remove(id, err)) < 0)
         {
-            QString error = QString().fromUtf8(err.c_str(), err.length());
-            if (!error.size())
-                mainwindow->get_error_http((MediaConchLib::errorHttp)code, error);
-            string_to_json(error);
-            json = QString("{\"error\":\"%1\"}").arg(error);
+            string_to_json(err);
+            json = QString("{\"error\":\"%1\"}").arg(err);
             return json;
         }
 
@@ -1039,15 +1100,12 @@ namespace MediaConch {
     {
         //return: error?
         QString json;
-        std::string err;
+        QString err;
         int code;
         if ((code = mainwindow->policy_export((size_t)id, err)) < 0)
         {
-            QString error = QString().fromUtf8(err.c_str(), err.length());
-            if (!error.size())
-                mainwindow->get_error_http((MediaConchLib::errorHttp)code, error);
-            string_to_json(error);
-            json = QString("{\"error\":\"%1\"}").arg(error);
+            string_to_json(err);
+            json = QString("{\"error\":\"%1\"}").arg(err);
             return json;
         }
 
@@ -1058,15 +1116,12 @@ namespace MediaConch {
     QString WebCommonPage::policy_export_data(const QString& report)
     {
         QString json;
-        std::string err;
+        QString err;
         int code;
         if ((code = mainwindow->policy_export_data(report, "Policy", err)) < 0)
         {
-            QString error = QString().fromUtf8(err.c_str(), err.length());
-            if (!error.size())
-                mainwindow->get_error_http((MediaConchLib::errorHttp)code, error);
-            string_to_json(error);
-            json = QString("{\"error\":\"%1\"}").arg(error);
+            string_to_json(err);
+            json = QString("{\"error\":\"%1\"}").arg(err);
             return json;
         }
 
@@ -1075,28 +1130,24 @@ namespace MediaConch {
     }
 
     QString WebCommonPage::policy_edit(int id, const QString& name, const QString& description, const QString& license,
-                                       const QString& type, const QString& visibility)
+                                       const QString& type, const QString&)
     {
         //return: error?
         QString json;
-        std::string err;
+        QString err;
         int code;
         if ((code = mainwindow->policy_change_info((size_t)id, name.toUtf8().data(), description.toUtf8().data(),
                                                    license.toUtf8().data(), err)) < 0)
         {
-            QString error = QString().fromUtf8(err.c_str(), err.length());
-            if (!error.size())
-                mainwindow->get_error_http((MediaConchLib::errorHttp)code, error);
-            string_to_json(error);
-            json = QString("{\"error\":\"%1\"}").arg(error);
+            string_to_json(err);
+            json = QString("{\"error\":\"%1\"}").arg(err);
             return json;
         }
 
         if (mainwindow->policy_change_type((size_t)id, type.toUtf8().data(), err) < 0)
         {
-            QString error = QString().fromUtf8(err.c_str(), err.length());
-            string_to_json(error);
-            json = QString("{\"error\":\"%1\"}").arg(error);
+            string_to_json(err);
+            json = QString("{\"error\":\"%1\"}").arg(err);
             return json;
         }
 
@@ -1115,9 +1166,9 @@ namespace MediaConch {
         mainwindow->policy_save(id, err);
 
         MediaConchLib::Get_Policy p;
-        if (mainwindow->policy_get(id, "JSTREE", p) < 0)
+        if (mainwindow->policy_get(id, "JSTREE", p, err) < 0)
         {
-            json = "{\"error\":\"Cannot import the policy\"}";
+            json = QString("{\"error\":\"") + err + "\"}";
             return json;
         }
 
@@ -1133,16 +1184,13 @@ namespace MediaConch {
 
     QString WebCommonPage::xslt_policy_rule_create(int policy_id)
     {
-        std::string err;
+        QString err;
         QString json;
         int new_rule_id = -1;
         if ((new_rule_id = mainwindow->xslt_policy_rule_create(policy_id, err)) < 0)
         {
-            QString error = QString().fromUtf8(err.c_str(), err.length());
-            if (!error.size())
-                mainwindow->get_error_http((MediaConchLib::errorHttp)new_rule_id, error);
-            string_to_json(error);
-            json = QString("{\"error\":\"%1\"}").arg(error);
+            string_to_json(err);
+            json = QString("{\"error\":\"%1\"}").arg(err);
             return json;
         }
 
@@ -1151,7 +1199,7 @@ namespace MediaConch {
         XsltPolicyRule* r = mainwindow->xslt_policy_rule_get(policy_id, new_rule_id, err);
         if (!r)
         {
-            json = "{\"error\":\"Cannot get the policy rule created\"}";
+            json = QString("{\"error\":\"") + err + "\"}";
             return json;
         }
 
@@ -1165,7 +1213,7 @@ namespace MediaConch {
 
     QString WebCommonPage::xslt_policy_rule_edit(int rule_id, int policy_id, const QString& title, const QString& type, const QString& field, int occurrence, const QString& ope, const QString& value, const QString& scope)
     {
-        std::string err;
+        QString err;
         QString json;
 
         XsltPolicyRule rule;
@@ -1180,11 +1228,8 @@ namespace MediaConch {
         int code;
         if ((code = mainwindow->xslt_policy_rule_edit(policy_id, rule_id, &rule, err)) < 0)
         {
-            QString error = QString().fromUtf8(err.c_str(), err.length());
-            if (!error.size())
-                mainwindow->get_error_http((MediaConchLib::errorHttp)code, error);
-            string_to_json(error);
-            json = QString("{\"error\":\"%1\"}").arg(error);
+            string_to_json(err);
+            json = QString("{\"error\":\"%1\"}").arg(err);
             return json;
         }
 
@@ -1208,16 +1253,13 @@ namespace MediaConch {
     QString WebCommonPage::xslt_policy_rule_duplicate(int policy_id, int rule_id, int dst_policy_id)
     {
         //return: rule
-        std::string err;
+        QString err;
         QString json;
         int new_rule_id = -1;
         if ((new_rule_id = mainwindow->xslt_policy_rule_duplicate(policy_id, rule_id, dst_policy_id, err)) < 0)
         {
-            QString error = QString().fromUtf8(err.c_str(), err.length());
-            if (!error.size())
-                mainwindow->get_error_http((MediaConchLib::errorHttp)new_rule_id, error);
-            string_to_json(error);
-            json = QString("{\"error\":\"%1\"}").arg(error);
+            string_to_json(err);
+            json = QString("{\"error\":\"%1\"}").arg(err);
             return json;
         }
 
@@ -1241,16 +1283,13 @@ namespace MediaConch {
     QString WebCommonPage::xslt_policy_rule_move(int policy_id, int rule_id, int dst_policy_id)
     {
         //return: rule
-        std::string err;
+        QString err;
         QString json;
         int new_rule_id = -1;
         if ((new_rule_id = mainwindow->xslt_policy_rule_move(policy_id, rule_id, dst_policy_id, err)) < 0)
         {
-            QString error = QString().fromUtf8(err.c_str(), err.length());
-            if (!error.size())
-                mainwindow->get_error_http((MediaConchLib::errorHttp)new_rule_id, error);
-            string_to_json(error);
-            json = QString("{\"error\":\"%1\"}").arg(error);
+            string_to_json(err);
+            json = QString("{\"error\":\"%1\"}").arg(err);
             return json;
         }
 
@@ -1274,16 +1313,14 @@ namespace MediaConch {
 
     QString WebCommonPage::xslt_policy_rule_delete(int policy_id, int rule_id)
     {
-        std::string err;
+        QString err;
         QString json;
         int code;
+
         if ((code = mainwindow->xslt_policy_rule_delete(policy_id, rule_id, err)) < 0)
         {
-            QString error = QString().fromUtf8(err.c_str(), err.length());
-            if (!error.size())
-                mainwindow->get_error_http((MediaConchLib::errorHttp)code, error);
-            string_to_json(error);
-            json = QString("{\"error\":\"%1\"}").arg(error);
+            string_to_json(err);
+            json = QString("{\"error\":\"%1\"}").arg(err);
             return json;
         }
 
