@@ -58,10 +58,16 @@ protected:
     QString      choose_file_import_policy();
     void         string_to_json(QString& str);
 
+private Q_SLOTS:
+    void         timer_menu_link();
+
 public Q_SLOTS:
-    void         on_file_upload_selected(const QString& policy, const QString& display, const QString& verbosity, bool fixer);
-    void         on_file_online_selected(const QString& url, const QString& policy, const QString& display, const QString& verbosity, bool fixer);
-    void         on_file_repository_selected(const QString& policy, const QString& display, const QString& verbosity, bool fixer);
+    QString      on_file_upload_selected(const QString& policy, const QString& display, const QString& verbosity,
+                                         bool fixer);
+    QString      on_file_online_selected(const QString& url, const QString& policy, const QString& display,
+                                         const QString& verbosity, bool fixer);
+    QString      on_file_repository_selected(const QString& policy, const QString& display,
+                                             const QString& verbosity, bool fixer);
     void         on_save_settings_selected(const QString& policy, const QString& display, const QString& verbosity,
                                            const QString& save_report, const QString& load_files,
                                            const QString& save_policy, const QString& load_policy,
@@ -104,6 +110,7 @@ public Q_SLOTS:
 
     QString      get_policies_tree();
     QString      policy_get_xml(int id);
+    QString      policy_get_jstree(int id);
     void         create_rule_tree(XsltPolicyRule *r, QString& rule_data);
     QString      import_policy();
     QString      import_policy(const QString& file);
@@ -134,6 +141,7 @@ protected:
     MainWindow                 *mainwindow;
     QMap<QString, QStringList>  file_selector;
     QString                     select_file_name;
+    QString                     menu_name;
 };
 
 }
