@@ -30,10 +30,24 @@ namespace MediaConch
     {
         connect(this, SIGNAL(loadFinished(bool)), this, SLOT(on_load_finished(bool)));
         QWebSettings::globalSettings()->setAttribute(QWebSettings::LocalContentCanAccessRemoteUrls, true);
+#if defined(QT_DEBUG)
+        settings()->setAttribute(QWebSettings::DeveloperExtrasEnabled, true);
+
+        inspector = new QWebInspector;
+        inspector->setPage(this);
+        inspector->setVisible(true);
+#endif
     }
 
     WebPage::~WebPage()
     {
+#if defined(QT_DEBUG)
+        if (inspector)
+        {
+            delete inspector;
+            inspector = NULL;
+        }
+#endif
         disconnect(this, SLOT(on_load_finished(bool)));
         QWebFrame* frame = mainFrame();
         if (frame)
