@@ -214,7 +214,8 @@ void CheckerWindow::hide()
 void CheckerWindow::create_policy_options(QString& policies)
 {
     MediaConchLib::Get_Policies list;
-    mainwindow->get_policies("JSON", list);
+    QString err;
+    mainwindow->get_policies("JSON", list, err);
 
     QString system_policy;
     QString user_policy;
@@ -594,6 +595,9 @@ void CheckerWindow::change_body_script_in_template(QString& html)
              "        <script type=\"text/javascript\" src=\"qrc:/webengine.js\"></script>\n"
              "        <script type=\"text/javascript\" src=\"qrc:/checker.js\"></script>\n";
 #endif
+    script += "       <script type=\"text/javascript\" src=\"qrc:/utils/url.js\"></script>\n";
+    script += "       <script type=\"text/javascript\" src=\"qrc:/menu.js\"></script>\n";
+
     if ((pos = reg.indexIn(html, pos)) != -1)
         html.replace(pos, reg.matchedLength(), script);
 }
