@@ -22,6 +22,7 @@ namespace MediaConch {
 class MainWindow;
 class WebView;
 class ProgressBar;
+class ResultTable;
 
 class CheckerWindow : public QObject
 {
@@ -35,38 +36,53 @@ public:
     void                        create_web_view();
     void                        set_display_xslt(const QString& d) { display_xslt = d; }
     void                        reset_display_xslt() { display_xslt.clear(); }
-    void                        change_local_files(QStringList& files);
+    void                        change_local_files(const QStringList& files);
     void                        hide();
+    void                        add_file_to_result_table(const std::string& full_path);
+    void                        page_start_waiting_loop();
 
 private:
     // Visual elements
     MainWindow*                 mainwindow;
-    WebView*                    MainView;
-    ProgressBar*                progressBar;
+    WebView*                    main_view;
+    ProgressBar*                progress_bar;
     QString                     display_xslt;
     unsigned int                result_index;
+    ResultTable                *result_table;
+    bool                        is_finished;
+    std::vector<std::string>    files;
 
-    void                        clearVisualElements();
+    void                        clear_visual_elements();
     void                        set_web_view_content(QString& html);
 
 //***************************************************************************
 // HELPER
 //***************************************************************************
 
+    void add_policy_to_html_selection(QString& policies, QString& html, const QString& selector);
+    void create_policy_options(QString& policies);
+    void add_display_to_html_selection(QString& displays, QString& html, const QString& selector);
+    void create_displays_options(QString& displays);
+    void add_verbosity_to_html_selection(QString& verbosity, QString& html, const QString& selector);
+    void create_verbosity_options(QString& verbosity);
     void remove_template_tags(QString& data);
     void load_include_in_template(QString& html);
     void remove_element_in_template(QString& html);
     void load_form_in_template(QString& html);
     QString create_html();
-    QString create_html_base(QString& body);
-    QString create_html_body();
+    void create_html_base(const QString& checker, const QString& result, QString& base);
+    void create_html_checker(QString&);
+    void create_html_result(QString&);
     QString create_form_upload();
     QString create_form_online();
     QString create_form_repository();
     void add_script_js_tree(std::string& file);
     void remove_form_online(int pos, QString& html);
     void change_collapse_form(QString& html);
-    void change_body_in_template(QString& body, QString& html);
+    void change_checker_in_template(const QString& checker, QString& html);
+    void change_result_in_template(const QString& result, QString& html);
+    void change_body_script_in_template(QString& html);
+    void set_webmachine_script_in_template(QString& html);
 #if defined(WEB_MACHINE_ENGINE)
     void add_file_detail_to_html(std::string& file, int policy);
 #endif
@@ -75,7 +91,7 @@ private:
 #endif
 
 private Q_SLOTS:
-    void createWebViewFinished(bool ok);
+    void create_web_view_finished(bool ok);
 };
 
 }
