@@ -3,7 +3,7 @@ $(document).ready(function() {
         'order': [],
         'autoWidth': false,
         'fixedHeader': {
-            headerOffset: $('#mco-navbar').outerHeight(true)
+            headerOffset: 70
         },
         'columnDefs': [
             { 'orderable': true, targets: 0 },
@@ -20,13 +20,19 @@ $(document).ready(function() {
     // Avoid call to checker status if it's already running
     checkerStatusInProgress = false;
 
+    //init error
+    mcoMessage.init('#checkerInfo div');
+
     // Upload form
     $('#file form').on('submit', function (e) {
         e.preventDefault();
-        webpage.on_file_upload_selected($('.tab-content .active .policyList').val(),
-                                        $('.tab-content .active .displayList').val(),
-                                        $('.tab-content .active .verbosityList').val(),
-                                        $('#checkerUpload_fixer').is(':checked'));
+        var err = webpage.on_file_upload_selected($('.tab-content .active .policyList').val(),
+                                                  $('.tab-content .active .displayList').val(),
+                                                  $('.tab-content .active .verbosityList').val(),
+                                                  $('#checkerUpload_fixer').is(':checked'));
+
+        if (err && err.length)
+            mcoMessage.error(err);
     });
 
     // Online form
@@ -114,15 +120,9 @@ $(document).ready(function() {
     };
 
     // help
-    addHelp('.checkerFixer label', 'Try to fix buggy files, technology preview, see <a href="https://mediaarea.net/MediaConch/fixity.html" onclick="call_tooltip_fixer(event);">the fixity webpage</a> for how to test it.', 'Fixer', 'checkerFixerHelp');
+    addHelp('.checkerFixer label', 'Try to fix buggy files, technology preview, see <a href="https://mediaarea.net/MediaConch/fixity.html" onclick="urlUtils.openInBrowser(event);">the fixity webpage</a> for how to test it.', 'Fixer', 'checkerFixerHelp');
 });
 
-function call_tooltip_fixer(e)
-{
-    e.preventDefault();
-    webpage.call_tooltip("https://mediaarea.net/MediaConch/fixity.html");
-}
-
 function getDataFromForm(form) {
     formValues = {policy:form.find('.policyList').val(),
                   policyText:form.find('.policyList option:selected').text(),
